@@ -280,12 +280,12 @@ class Base(base_method):
             show_sql = False
         if show_sql is True:
             dbg('sql_id', id(self), dummy_sql)
-        if self._engine != sqlite:
-            try:
-                await self.db.ping(reconnect=True)
-            except Exception as e:
-                dbg(id(self),dummy_sql, 'db error', str(e), 'reconnecting...')
-                await self.connect()
+        # if self._engine != sqlite:
+        try:
+            await self.db.ping(reconnect=True)
+        except Exception as e:
+            dbg(id(self),dummy_sql, 'db error', str(e), 'reconnecting...')
+            await self.connect()
 
         cursor = await self.db.cursor()
 
